@@ -25,10 +25,15 @@ import settings
 def help_string():
     overview = 'This is a convenience script for auto-generating a catkin parallel build directory.\n\n'
     instructions = " \
- 'yujin_init_build' prepares conventional ros build directories in ./ linked to sources in ./src \n \
+ 'yujin_init_build .' prepares conventional ros build directories in ./ linked to sources in ./src \n \
+ 'yujin_init_build .' prepares conventional ros build directories in ./ linked to sources in ./src \n \
  'yujin_init_build --release release' prepares a release directory in ./release linked to sources in ./src \n \
  'yujin_init_build debug ~/ecl/src' prepares a build directory in ./debug linked to sources in ~/ecl/src \n \
- 'yujin_init_build --toolchain=arm-pc-linux-gnueabi arm' prepares a build directory in ./arm with the specified toolchain module \n \
+ 'yujin_init_build --no-default-underlay --toolchain=arm-pc-linux-gnueabi arm' prepares a build directory in ./arm with the specified toolchain module \n \
+ 'yujin_init_build --underlays=~/cslam/src/native;~/ecl/src/native .' prepares a build directory in ./arm with the specified toolchain module \n \
+ \n \
+ Underlays automatically add /opt/ros/`yujin_tools_settings --get-default-track` unless '--no-default-underlay' is specified (in which case you should\n \
+ ensure that the catkin sources are in your workspace or one of your underlays).\n \
 "
     return overview + instructions
 
@@ -39,13 +44,17 @@ def parse_arguments():
     parser.add_argument('sources', nargs='?', default="src", help='directory where the sources reside [./src]')
     parser.add_argument('-r', '--release', action='store_true', help='build in Release mode instead of RelWithDebugSymbols [false]')
     parser.add_argument('-i', '--install', action='store', default='/not_set_directory', help='installation location [workspace/install]')
-    parser.add_argument('-u', '--underlays', action='store', default='', help='semi-colon list of catkin workspaces to utilise, priority given from front to back [/opt/ros/groovy]')
+    #  even though we don't set a default value here, it later gets set as the default underlay if not present and --no-default-underlay is not true
+    parser.add_argument('-u', '--underlays', action='store', default='', help='semi-colon list of catkin workspaces to utilise, priority given from front to back')
+    default_underlay_group = parser.add_mutually_exclusive_group()
+    default_underlay_group.add_argument('-d', '--default-underlay', choices=['groovy', 'hydro'], action='store', default=None, help='default the underlays to this track if catkin is not found [`yujin_tools_settings --get-default-track`]')
+    default_underlay_group.add_argument('--track', choices=['groovy', 'hydro'], dest='default_underlay', action='store', default=None, help='convenience equivalent for the --default-underlay option')
+    default_underlay_group.add_argument('-n', '--no-default-underlay', action='store_true', help='do not automatically underlay with the default track setting [false]')
     parser.add_argument('-t', '--toolchain', action='store', default='', help='toolchain cmake module to load []')
     parser.add_argument('-p', '--platform', action='store', default='default', help='platform cmake cache module to load [default]')
     parser.add_argument('-c', '--clean', action='store_true', help='cleans the current or specified build directory [false]')
     parser.add_argument('--list-toolchains', action='store_true', help='list all currently available toolchain modules [false]')
     parser.add_argument('--list-platforms', action='store_true', help='list all currently available platform modules [false]')
-    parser.add_argument('--track', action='store', default=None, help='default the underlays to this track if catkin is not found [groovy|hydro][groovy]')
     args = parser.parse_args()
     return args
 
@@ -202,7 +211,7 @@ def list_platforms():
     console.pretty_println("**********************************************************************************\n", console.bold)
 
 
-def init_configured_build(track, build_dir_="./", source_dir_="./src", underlays_="/opt/ros/groovy", install_prefix_="./install", release_=False, toolchain_="", platform_=""):
+def init_configured_build(default_underlay, build_dir_="./", source_dir_="./src", underlays_="/opt/ros/groovy", install_prefix_="./install", release_=False, toolchain_="", platform_=""):
     '''
       This one is used with pre-configured parameters. Note that
       init_build generates parameters parsed from the command line and then
@@ -272,12 +281,12 @@ def init_configured_build(track, build_dir_="./", source_dir_="./src", underlays
     # Add toplevel if exists
     ##########################
     if not catkin_toplevel:
-        # Add the default track underlay
-        if os.path.isfile(os.path.join("/opt/ros/%s" % track, 'share', 'catkin', 'cmake', 'toplevel.cmake')):
-            catkin_toplevel = os.path.join("/opt/ros/%s" % track, 'share', 'catkin', 'cmake', 'toplevel.cmake')
-            unused_catkin_python_path = os.path.join("/opt/ros/%s" % track, 'lib', 'python2.7', 'dist-packages')
-            console.pretty_println("No catkin found, adding the default track underlay (use yujin_tools_settings to change) [/opt/ros/%s]" % track, console.cyan)
-            underlays_list.append("/opt/ros/%s" % track)
+        # Add the default underlay
+        if default_underlay is not None and os.path.isfile(os.path.join("/opt/ros/%s" % default_underlay, 'share', 'catkin', 'cmake', 'toplevel.cmake')):
+            catkin_toplevel = os.path.join("/opt/ros/%s" % default_underlay, 'share', 'catkin', 'cmake', 'toplevel.cmake')
+            unused_catkin_python_path = os.path.join("/opt/ros/%s" % default_underlay, 'lib', 'python2.7', 'dist-packages')
+            console.pretty_println("No catkin found, adding the default underlay (use yujin_tools_settings to change) [/opt/ros/%s]" % default_underlay, console.cyan)
+            underlays_list.append("/opt/ros/%s" % default_underlay)
         else:
             raise RuntimeError("Could not find an underlying catkin installation.")
     common.create_symlink(catkin_toplevel, os.path.join(build_source_dir, "CMakeLists.txt"))
@@ -399,11 +408,15 @@ def clean(dir_to_be_cleaned, dir_sources):
 
 def init_build():
     args = parse_arguments()
+
     ##########################
-    # Tracks
+    # Default underlays
     ##########################
-    if not args.track:
-        args.track = settings.get_default_track()
+    if args.no_default_underlay:
+        args.default_underlay = None
+    elif not args.default_underlay:
+        args.default_underlay = settings.get_default_track()
+
     ##########################
     # Toolchains and Platform
     ##########################
@@ -416,4 +429,4 @@ def init_build():
     if args.clean:
         clean(args.dir, args.sources)
         return
-    init_configured_build(args.track, args.dir, args.sources, args.underlays, args.install, args.release, args.toolchain, args.platform)
+    init_configured_build(args.default_underlay, args.dir, args.sources, args.underlays, args.install, args.release, args.toolchain, args.platform)
